==> amaya-src-5.1.tgz: Amaya/amaya/amayamsg.h <==

/* Beginning of labels */
#define AM_FILES		0
#define AM_OPEN_URL		1
#define AM_CLEAR		2
#define AM_SAVED		3
#define AM_ATTRIBUTE		4
#define AM_HREF_VALUE		5
#define AM_TEXT		6
#define AM_NAME		7
#define AM_PASSWORD		8
#define AM_DEF_CLASS		9
#define AM_APPLY_CLASS		10
#define AM_SEL_CLASS		11
#define AM_FETCHING		12
#define AM_CANNOT_LOAD		13
#define AM_DOCUMENT_LOADED		14
#define AM_SEL_TARGET		15
#define AM_INVALID_TARGET		16
#define AM_LOCATION		17
#define AM_TITLE		18
#define AM_DOC_MODIFIED		19
#define AM_RED_FETCHING		20
#define AM_REDIRECTIONS_LIMIT		21
#define AM_CANNOT_CREATE_FILE		22
#define AM_WAITING_FOR_SOCKET		23
#define AM_PROG_READ		24
#define AM_PROG_WRITE		25
#define AM_WAITING_FOR_CONNECTION		26
#define AM_CONTACTING_HOST		27
#define AM_LOOKING_HOST		28
#define AM_UNKNOWN_STATUS		29
#define AM_GET_AUTHENTICATION		30
#define AM_GET_AUTHENTICATION_MSG		31
#define AM_AUTHENTICATION_FAILURE		32
#define AM_LOADED_NO_DATA		33
#define AM_LOAD_ABORT		34
#define AM_NOT_AVAILABLE_RETRY		35
#define AM_ELEMENT_LOADED		36
#define AM_REMOTE_SAVING		37
#define AM_CANNOT_SAVE		38
#define AM_SYSTEM_ERROR		39
#define AM_INVALID_ANCHOR1		40
#define AM_INVALID_ANCHOR2		41
#define AM_GET_UNSUPPORTED_PROTOCOL		42
#define AM_PUT_UNSUPPORTED_PROTOCOL		43
#define AM_UNSUPPORTED_FEATURE		44
#define AM_WROTE_OBJECT		45
#define AM_BAD_URL		46
#define AM_CACHE_ERROR		47
#define AM_NO_TRANS		48
#define AM_TRANS_FAILED		49
#define AM_TRANS_PARSE_ERROR		50
#define AM_BUTTON_MATH		51
#define AM_BUTTON_GRAPHICS		52
#define AM_SAVE_AS		53
#define AM_AUTHENTICATION_REALM_SERVER		54
#define AM_AUTHENTICATION_REALM		55
#define AM_AUTHENTICATION_SERVER		56
#define AM_BUTTON_BrowseEdit		57
#define AM_REQUEST_TIMEOUT		58
#define AM_OVERWRITE_CHECK		59
#define AM_ETAG_CHANGED		60
#define AM_BACKGROUND_IMAGE		61
#define AM_BG_IMAGE_NOT_ALLOWED		62
#define AM_CSS		63
#define AM_WARNING_SAVE_OVERWRITE		64
#define AM_URL_SAVE_FAILED		65
#define AM_SAVE_DISK		66
#define AM_BCOPY_IMAGES		67
#define AM_BTRANSFORM_URL		68
#define AM_DOC_LOCATION		69
#define AM_IMAGES_LOCATION		70
#define AM_OBJECT_LOCATION		71
#define AM_CSS_FILE		72
#define AM_ABOUT1		73
#define AM_ABOUT2		74
#define AM_TOO_LONG_URL		75
#define AM_INVALID_TYPE		76
#define AM_UPDATED_LINK		77
#define AM_NOTHING_TO_SAVE		78
#define AM_REPEAT_Y		79
#define AM_SYS_ERROR_TMPL		80
#define AM_GET_USER_NAME		81
#define AM_WAITING_REQUESTS		82
#define AM_NO_CCS_FILE		83
#define AM_BUTTON_INTERRUPT		84
#define AM_BUTTON_PREVIOUS		85
#define AM_BUTTON_NEXT		86
#define AM_BUTTON_RELOAD		87
#define AM_BUTTON_SAVE		88
#define AM_BUTTON_PRINT		89
#define AM_BUTTON_SEARCH		90
#define AM_BUTTON_ITALICS		91
#define AM_BUTTON_BOLD		92
#define AM_BUTTON_CODE		93
#define AM_NO_REPEAT		94
#define AM_BUTTON_IMG		95
#define AM_BUTTON_H1		96
#define AM_BUTTON_H2		97
#define AM_BUTTON_H3		98
#define AM_BUTTON_UL		99
#define AM_BUTTON_OL		100
#define AM_BUTTON_DL		101
#define AM_BUTTON_LINK		102
#define AM_BUTTON_TABLE		103
#define AM_NO_NAME		104
#define AM_BUTTON_PLUGIN		105
#define AM_UNKNOWN_SAVE_ERROR		106
#define AM_CANT_CONNECT_TO_HOST		107
#define AM_FORBIDDEN_ACCESS		108
#define AM_REQUEST_SUCCEEDED		109
#define AM_CREATED_NEW_REMOTE_RESSOURCE		110
#define AM_UPDATED_REMOTE_RESSOURCE		111
#define AM_UNKNOWN_XXX_STATUS		112
#define AM_SERVER_DID_NOT_UNDERSTAND_REQ_SYNTAX		113
#define AM_NO_DATA		114
#define AM_METHOD_NOT_ALLOWED		115
#define AM_PLEASE_AUTHENTICATE		116
#define AM_VERIFYING		117
#define AM_SAVING_FAILED		118
#define AM_SAVE_COMPARE_FAILED		119
#define AM_SAVE_REDIRECTED		120
#define AM_SAVE_RELOAD_FAILED		121
#define AM_SERVER_INTERNAL_ERROR_500_CAUSE		122
#define AM_SERVER_INTERNAL_ERROR_500_NO_CAUSE		123
#define AM_SERVER_NOT_IMPLEMENTED_501_ERROR		124
#define AM_PARSE		125
#define AM_ACTIVE_TRANSFERS		126
#define AM_WAITING_TRANSFERS		127
#define AM_PRINT_TOC		128
#define AM_NUMBERED_LINKS		129
#define AM_REPEAT_MODE		130
#define AM_REPEAT		131
#define AM_REPEAT_X		132
#define AM_RELOAD_FILES		133
#define AM_AUTHENTICATION_CONFIRM		134
#define AM_REDIRECTION_CONFIRM		135
#define AM_ROWS		136
#define AM_COLS		137
#define AM_BORDER		138
#define AM_ALT		139
#define AM_ALT_MISSING		140
#define AM_PRINT_URL		141
#define AM_APPLY_BUTTON		142
#define AM_DEFAULT_BUTTON		143
#define AM_FLUSH_CACHE_BUTTON		144
#define AM_CACHE_MENU		145
#define AM_ENABLE_CACHE		146
#define AM_CACHE_PROT_DOCS		147
#define AM_DISCONNECTED_MODE		148
#define AM_IGNORE_EXPIRES		149
#define AM_CACHE_DIR		150
#define AM_CACHE_SIZE		151
#define AM_CACHE_ENTRY_SIZE		152
#define AM_PROXY_MENU		153
#define AM_HTTP_PROXY		154
#define AM_PROXY_DOMAIN		155
#define AM_GENERAL_MENU		156
#define AM_HOME_PAGE		157
#define AM_TOOLTIP_DELAY		158
#define AM_DOUBLECLICK_DELAY		159
#define AM_MENU_FONT_SIZE		160
#define AM_ZOOM		161
#define AM_DIALOGUE_LANGUAGE		162
#define AM_ENABLE_MULTIKEY		163
#define AM_SHOW_BG_IMAGES		164
#define AM_ENABLE_DOUBLECLICK		165
#define AM_PUBLISH_MENU		166
#define AM_USE_ETAGS		167
#define AM_VERIFY_PUT		168
#define AM_DEFAULT_NAME		169
#define AM_GEOMETRY_MENU		170
#define AM_SAVE_GEOMETRY		171
#define AM_RESTORE_GEOMETRY		172
#define AM_GEOMETRY_CHANGE		173
#define AM_COLOR_MENU		174
#define AM_DOC_FG_COLOR		175
#define AM_DOC_BG_COLOR		176
#define AM_MENU_FG_COLOR		177
#define AM_MENU_BG_COLOR		178
#define AM_CANT_CREATE_CACHE		179
#define AM_BUTTON_HOME		180
#define AM_LANG_NEGOTIATION		181
#define AM_PROFILES_FILE		182
#define AM_PROFILE_SELECT		183
#define AM_PROFILE_CHANGE		184
#define AM_PROFILE_MENU		185
#define AM_TEMPLATES_SERVER		186
#define AM_TEMPLATES_MENU		187
#define AM_SAFE_PUT_REDIRECT		188
#define AM_WITH_CSS		189
#define AM_TRANS		190
#define AM_PROXY_DOMAIN_INFO		191
#define AM_DONT_PROXY_DOMAIN		192
#define AM_ONLY_PROXY_DOMAIN		193
#define AM_MATH_ENTITY_NAME		194
#define AM_USER_DIR		195
#define AM_TMP_DIR		196
#define AM_COLOR_PALETTE		197
#define AM_LANNEG_MENU		198
#define AM_ANNOT_CONF_MENU		199
#define AM_ANNOT_USER		200
#define AM_ANNOT_POST_SERVER		201
#define AM_ANNOT_SERVERS		202
#define AM_ANNOT_LAUTOLOAD		203
#define AM_ANNOT_RAUTOLOAD		204
#define AM_ANNOT_RAUTOLOAD_RST		205
#define AM_DOC_SEL_COLOR		206
#define AM_DOC_INS_COLOR		207
#define AM_ORIENTATION		208
#define AM_PORTRAIT		209
#define AM_LANDSCAPE		210
#define AM_ENABLE_FTP		211
#define AM_XML_NOT_WELL_FORMED		212
#define AM_XML_CHARACTER_ERROR		213
#define AM_XML_PROFILE		214
#define AM_XML_ERROR		215
#define AM_UNKNOWN_ENCODING		216
#define AM_UNDEFINED_ENCODING		217
#define AM_UNDEFINED_ENCODING_CONFIRM		218
#define AM_NOT_AVAILABLE		219
#define AM_BROWSE		220
#define AM_FILE_BROWSER		221
#define AM_SELECTION		222
#define AM_AFILTER		223
#define AM_AFILTER_SHOW		224
#define AM_AFILTER_HIDE		225
#define AM_AFILTER_SHOW_ALL		226
#define AM_AFILTER_HIDE_ALL		227
#define AM_AFILTER_HELP		228
#define AM_AFILTER_OPTIONS		229
#define AM_AFILTER_BYAUTHOR		230
#define AM_AFILTER_BYTYPE		231
#define AM_AFILTER_BYSERVER		232
#define AM_ACCESSKEY		233
#define AM_NONE		234
#define AM_LOCAL_CSS		235
#define AM_NO_XPOINTER		236
#define AM_NO_ANNOT_MOVE		237
#define AM_NO_ANNOT_MOVE_OTHER		238
#define AM_SELECT_CHARSET		239
#define AM_SELECT_MIMETYPE		240
#define AM_CHANGE_CHARSET		241
#define AM_CHANGE_MIME_TYPE		242
#define AM_CHANGE		243
#define AM_NOCHARSET_SUPPORT		244
#define AM_NOMIMETYPE_SUPPORT		245
#define AM_INVALID_MIMETYPE		246
#define AM_UNKNOWN		247
#define AM_CSS_ERROR		248
#define AM_DOUBLE_LOAD		249
#define AM_UNSAVE		250
#define AMAYA_MSG_MAX		251

==> amaya-src-5.3.tgz: Amaya/amaya/amayamsg.h <==

/* Beginning of labels */
#define AM_FILES		0
#define AM_OPEN_URL		1
#define AM_CLEAR		2
#define AM_SAVED		3
#define AM_ATTRIBUTE		4
#define AM_HREF_VALUE		5
#define AM_TEXT		6
#define AM_NAME		7
#define AM_PASSWORD		8
#define AM_DEF_CLASS		9
#define AM_APPLY_CLASS		10
#define AM_SEL_CLASS		11
#define AM_FETCHING		12
#define AM_CANNOT_LOAD		13
#define AM_DOCUMENT_LOADED		14
#define AM_SEL_TARGET		15
#define AM_INVALID_TARGET		16
#define AM_LOCATION		17
#define AM_TITLE		18
#define AM_DOC_MODIFIED		19
#define AM_RED_FETCHING		20
#define AM_REDIRECTIONS_LIMIT		21
#define AM_CANNOT_CREATE_FILE		22
#define AM_WAITING_FOR_SOCKET		23
#define AM_PROG_READ		24
#define AM_PROG_WRITE		25
#define AM_WAITING_FOR_CONNECTION		26
#define AM_CONTACTING_HOST		27
#define AM_LOOKING_HOST		28
#define AM_UNKNOWN_STATUS		29
#define AM_GET_AUTHENTICATION		30
#define AM_GET_AUTHENTICATION_MSG		31
#define AM_AUTHENTICATION_FAILURE		32
#define AM_LOADED_NO_DATA		33
#define AM_LOAD_ABORT		34
#define AM_NOT_AVAILABLE_RETRY		35
#define AM_ELEMENT_LOADED		36
#define AM_REMOTE_SAVING		37
#define AM_CANNOT_SAVE		38
#define AM_SYSTEM_ERROR		39
#define AM_INVALID_ANCHOR1		40
#define AM_INVALID_ANCHOR2		41
#define AM_GET_UNSUPPORTED_PROTOCOL		42
#define AM_PUT_UNSUPPORTED_PROTOCOL		43
#define AM_UNSUPPORTED_FEATURE		44
#define AM_WROTE_OBJECT		45
#define AM_BAD_URL		46
#define AM_CACHE_ERROR		47
#define AM_NO_TRANS		48
#define AM_TRANS_FAILED		49
#define AM_TRANS_PARSE_ERROR		50
#define AM_BUTTON_MATH		51
#define AM_BUTTON_GRAPHICS		52
#define AM_SAVE_AS		53
#define AM_AUTHENTICATION_REALM_SERVER		54
#define AM_AUTHENTICATION_REALM		55
#define AM_AUTHENTICATION_SERVER		56
#define AM_BUTTON_BrowseEdit		57
#define AM_REQUEST_TIMEOUT		58
#define AM_OVERWRITE_CHECK		59
#define AM_ETAG_CHANGED		60
#define AM_BACKGROUND_IMAGE		61
#define AM_BG_IMAGE_NOT_ALLOWED		62
#define AM_CSS		63
#define AM_WARNING_SAVE_OVERWRITE		64
#define AM_URL_SAVE_FAILED		65
#define AM_SAVE_DISK		66
#define AM_BCOPY_IMAGES		67
#define AM_BTRANSFORM_URL		68
#define AM_DOC_LOCATION		69
#define AM_IMAGES_LOCATION		70
#define AM_OBJECT_LOCATION		71
#define AM_CSS_FILE		72
#define AM_ABOUT1		73
#define AM_ABOUT2		74
#define AM_TOO_LONG_URL		75
#define AM_INVALID_TYPE		76
#define AM_UPDATED_LINK		77
#define AM_NOTHING_TO_SAVE		78
#define AM_REPEAT_Y		79
#define AM_SYS_ERROR_TMPL		80
#define AM_GET_USER_NAME		81
#define AM_WAITING_REQUESTS		82
#define AM_NO_CCS_FILE		83
#define AM_BUTTON_INTERRUPT		84
#define AM_BUTTON_PREVIOUS		85
#define AM_BUTTON_NEXT		86
#define AM_BUTTON_RELOAD		87
#define AM_BUTTON_SAVE		88
#define AM_BUTTON_PRINT		89
#define AM_BUTTON_SEARCH		90
#define AM_BUTTON_ITALICS		91
#define AM_BUTTON_BOLD		92
#define AM_BUTTON_CODE		93
#define AM_NO_REPEAT		94
#define AM_BUTTON_IMG		95
#define AM_BUTTON_H1		96
#define AM_BUTTON_H2		97
#define AM_BUTTON_H3		98
#define AM_BUTTON_UL		99
#define AM_BUTTON_OL		100
#define AM_BUTTON_DL		101
#define AM_BUTTON_LINK		102
#define AM_BUTTON_TABLE		103
#define AM_NO_NAME		104
#define AM_BUTTON_PLUGIN		105
#define AM_UNKNOWN_SAVE_ERROR		106
#define AM_CANT_CONNECT_TO_HOST		107
#define AM_FORBIDDEN_ACCESS		108
#define AM_REQUEST_SUCCEEDED		109
#define AM_CREATED_NEW_REMOTE_RESSOURCE		110
#define AM_UPDATED_REMOTE_RESSOURCE		111
#define AM_UNKNOWN_XXX_STATUS		112
#define AM_SERVER_DID_NOT_UNDERSTAND_REQ_SYNTAX		113
#define AM_NO_DATA		114
#define AM_METHOD_NOT_ALLOWED		115
#define AM_PLEASE_AUTHENTICATE		116
#define AM_VERIFYING		117
#define AM_SAVING_FAILED		118
#define AM_SAVE_COMPARE_FAILED		119
#define AM_SAVE_REDIRECTED		120
#define AM_SAVE_RELOAD_FAILED		121
#define AM_SERVER_INTERNAL_ERROR_500_CAUSE		122
#define AM_SERVER_INTERNAL_ERROR_500_NO_CAUSE		123
#define AM_SERVER_NOT_IMPLEMENTED_501_ERROR		124
#define AM_PARSE		125
#define AM_ACTIVE_TRANSFERS		126
#define AM_WAITING_TRANSFERS		127
#define AM_PRINT_TOC		128
#define AM_NUMBERED_LINKS		129
#define AM_REPEAT_MODE		130
#define AM_REPEAT		131
#define AM_REPEAT_X		132
#define AM_RELOAD_FILES		133
#define AM_AUTHENTICATION_CONFIRM		134
#define AM_REDIRECTION_CONFIRM		135
#define AM_ROWS		136
#define AM_COLS		137
#define AM_BORDER		138
#define AM_ALT		139
#define AM_ALT_MISSING		140
#define AM_PRINT_URL		141
#define AM_APPLY_BUTTON		142
#define AM_DEFAULT_BUTTON		143
#define AM_FLUSH_CACHE_BUTTON		144
#define AM_CACHE_MENU		145
#define AM_ENABLE_CACHE		146
#define AM_CACHE_PROT_DOCS		147
#define AM_DISCONNECTED_MODE		148
#define AM_IGNORE_EXPIRES		149
#define AM_CACHE_DIR		150
#define AM_CACHE_SIZE		151
#define AM_CACHE_ENTRY_SIZE		152
#define AM_PROXY_MENU		153
#define AM_HTTP_PROXY		154
#define AM_PROXY_DOMAIN		155
#define AM_GENERAL_MENU		156
#define AM_HOME_PAGE		157
#define AM_TOOLTIP_DELAY		158
#define AM_DOUBLECLICK_DELAY		159
#define AM_MENU_FONT_SIZE		160
#define AM_ZOOM		161
#define AM_DIALOGUE_LANGUAGE		162
#define AM_ENABLE_MULTIKEY		163
#define AM_SHOW_BG_IMAGES		164
#define AM_ENABLE_DOUBLECLICK		165
#define AM_EXPORT_CRLF		166
#define AM_PUBLISH_MENU		167
#define AM_USE_ETAGS		168
#define AM_VERIFY_PUT		169
#define AM_DEFAULT_NAME		170
#define AM_GEOMETRY_MENU		171
#define AM_SAVE_GEOMETRY		172
#define AM_RESTORE_GEOMETRY		173
#define AM_GEOMETRY_CHANGE		174
#define AM_COLOR_MENU		175
#define AM_DOC_FG_COLOR		176
#define AM_DOC_BG_COLOR		177
#define AM_MENU_FG_COLOR		178
#define AM_MENU_BG_COLOR		179
#define AM_CANT_CREATE_CACHE		180
#define AM_BUTTON_HOME		181
#define AM_LANG_NEGOTIATION		182
#define AM_PROFILES_FILE		183
#define AM_PROFILE_SELECT		184
#define AM_PROFILE_CHANGE		185
#define AM_PROFILE_MENU		186
#define AM_TEMPLATES_SERVER		187
#define AM_TEMPLATES_MENU		188
#define AM_SAFE_PUT_REDIRECT		189
#define AM_WITH_CSS		190
#define AM_TRANS		191
#define AM_PROXY_DOMAIN_INFO		192
#define AM_DONT_PROXY_DOMAIN		193
#define AM_ONLY_PROXY_DOMAIN		194
#define AM_MATH_ENTITY_NAME		195
#define AM_USER_DIR		196
#define AM_TMP_DIR		197
#define AM_COLOR_PALETTE		198
#define AM_LANNEG_MENU		199
#define AM_ANNOT_CONF_MENU		200
#define AM_ANNOT_USER		201
#define AM_ANNOT_POST_SERVER		202
#define AM_ANNOT_SERVERS		203
#define AM_ANNOT_LAUTOLOAD		204
#define AM_ANNOT_RAUTOLOAD		205
#define AM_ANNOT_RAUTOLOAD_RST		206
#define AM_DOC_SEL_COLOR		207
#define AM_DOC_INS_COLOR		208
#define AM_ORIENTATION		209
#define AM_PORTRAIT		210
#define AM_LANDSCAPE		211
#define AM_ENABLE_FTP		212
#define AM_XML_RETRY		213
#define AM_XML_ERROR		214
#define AM_XML_CHARACTER_RETRY		215
#define AM_XML_CHARACTER_ERROR		216
#define AM_XML_PROFILE		217
#define AM_XML_WARNING		218
#define AM_UNKNOWN_ENCODING		219
#define AM_XML_MISMATCH_PROFILE		220
#define AM_NOT_AVAILABLE		221
#define AM_BROWSE		222
#define AM_FILE_BROWSER		223
#define AM_SELECTION		224
#define AM_AFILTER		225
#define AM_AFILTER_SHOW		226
#define AM_AFILTER_HIDE		227
#define AM_AFILTER_SHOW_ALL		228
#define AM_AFILTER_HIDE_ALL		229
#define AM_AFILTER_HELP		230
#define AM_AFILTER_OPTIONS		231
#define AM_AFILTER_BYAUTHOR		232
#define AM_AFILTER_BYTYPE		233
#define AM_AFILTER_BYSERVER		234
#define AM_ACCESSKEY		235
#define AM_NONE		236
#define AM_LOCAL_CSS		237
#define AM_NO_XPOINTER		238
#define AM_NO_SXPOINTER		239
#define AM_NO_EXPOINTER		240
#define AM_NO_ANNOT_MOVE		241
#define AM_NO_ANNOT_MOVE_OTHER		242
#define AM_NO_ANNOT_MOD_DOC		243
#define AM_NO_ANNOT_USER		244
#define AM_CANNOT_ANNOTATE		245
#define AM_NEW_ANNOTATION		246
#define AM_ANNOT_POST_FAILURE		247
#define AM_ANNOT_DELETE_FAILURE		248
#define AM_ANNOT_DELETED		249
#define AM_ANNOT_INDEX_FAILURE		250
#define AM_ERROR		251
#define AM_SELECT_CHARSET		252
#define AM_SELECT_MIMETYPE		253
#define AM_CHANGE_CHARSET		254
#define AM_CHANGE_MIME_TYPE		255
#define AM_CHANGE		256
#define AM_NOCHARSET_SUPPORT		257
#define AM_NOMIMETYPE_SUPPORT		258
#define AM_INVALID_MIMETYPE		259
#define AM_UNKNOWN		260
#define AM_CSS_ERROR		261
#define AM_DOUBLE_LOAD		262
#define AM_UNSAVE		263
#define AMAYA_MSG_MAX		264
